'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _getElementPosition = require('./utils/getElementPosition');

var _setSources = require('./utils/setSources');

var _setConfig = require('./utils/setConfig');

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var LazyLoadWW = function LazyLoadWW() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var config = (0, _setConfig.setConfig)(props);

  var $els = document.querySelectorAll('.' + config.lazyClass);
  if (!$els.length) return;

  var wHeight = window.innerHeight;

  if (config.placeholderSrc) [].concat(_toConsumableArray($els)).forEach(function ($el) {
    var rect = (0, _getElementPosition.getElementPosition)($el);
    if (rect - wHeight <= config.distanceToVisibleArea) return;
    $el.src = config.placeholderSrc;
  });

  var onDocumentScroll = function onDocumentScroll() {
    [].concat(_toConsumableArray($els)).forEach(function ($el) {
      var rect = (0, _getElementPosition.getElementPosition)($el);
      if (rect - wHeight > config.distanceToVisibleArea) return;

      ///////////////   Start of loading notification   ////////////////
      $el.classList.remove(config.lazyClass);
      $el.classList.add(config.loadingClass);
      ///////////////   /Start of loading notification   ///////////////

      /////////////////////       Set sources       ////////////////////
      var hasSource = $el.hasAttribute('data-source-mobile') || $el.hasAttribute('data-source-tablet') || $el.hasAttribute('data-source-desktop') || $el.hasAttribute('data-source-xl');

      /*      Img sources    */
      if (hasSource && $el.tagName.toLowerCase() === 'img') (0, _setSources.setSourcesToImg)($el, config.breakpoints);
      /*     Video sources   */
      else if (hasSource && $el.toLowerCase() === 'video') (0, _setSources.setSourcesToVideo)($el, config.breakpoints);
      /////////////////////      /Set sources       ////////////////////

      /////////////////////       Set img src       ////////////////////
      $el.src = $el.dataset.src;
      ////////////////////       /Set img src       ////////////////////

      ////////////////////      Set img srcset      ////////////////////
      var srcset = $el.dataset.srcset;
      if (srcset) $el.srcset = srcset;
      ////////////////////      /Set img srcset     ////////////////////


      ////////////////   End of download notification   ////////////////
      $el.onload = function () {
        $el.classList.remove(config.loadingClass);
        $el.setAttribute('class', config.loadedClass);
      };
      ////////////////   /End of download notification   ////////////////
    });

    $els = document.querySelectorAll('.' + config.lazyClass);
    if (!$els.length) return document.removeEventListener('scroll', onDocumentScroll);
  };

  document.addEventListener('scroll', onDocumentScroll);
  onDocumentScroll();
};

exports.default = LazyLoadWW;